nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ctrl1

Struct Ctrl1 

#[repr(transparent)]
pub struct Ctrl1(pub u32);
LCDIF General Control1 Register

Tuple Fields

0: u32

Implementations

Source

impl Ctrl1

pub const fn vsync_edge_irq(&self) -> bool

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn set_vsync_edge_irq(&mut self, val: bool)

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn cur_frame_done_irq(&self) -> bool

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn set_cur_frame_done_irq(&mut self, val: bool)

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn underflow_irq(&self) -> bool

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn set_underflow_irq(&mut self, val: bool)

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn overflow_irq(&self) -> bool

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn set_overflow_irq(&mut self, val: bool)

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn vsync_edge_irq_en(&self) -> bool

This bit is set to enable an interrupt every time the hardware encounters the leading VSYNC edge in the VSYNC and DOTCLK modes, or the beginning of every field in DVI mode

pub const fn set_vsync_edge_irq_en(&mut self, val: bool)

This bit is set to enable an interrupt every time the hardware encounters the leading VSYNC edge in the VSYNC and DOTCLK modes, or the beginning of every field in DVI mode

pub const fn cur_frame_done_irq_en(&self) -> bool

This bit is set to 1 enable an interrupt every time the hardware enters in the vertical blanking state

pub const fn set_cur_frame_done_irq_en(&mut self, val: bool)

This bit is set to 1 enable an interrupt every time the hardware enters in the vertical blanking state

pub const fn underflow_irq_en(&self) -> bool

This bit is set to enable an underflow interrupt in the TXFIFO in the write mode.

pub const fn set_underflow_irq_en(&mut self, val: bool)

This bit is set to enable an underflow interrupt in the TXFIFO in the write mode.

pub const fn overflow_irq_en(&self) -> bool

This bit is set to enable an overflow interrupt in the TXFIFO in the write mode.

pub const fn set_overflow_irq_en(&mut self, val: bool)

This bit is set to enable an overflow interrupt in the TXFIFO in the write mode.

pub const fn byte_packing_format(&self) -> u8

This bitfield is used to show which data bytes in a 32-bit word are valid

pub const fn set_byte_packing_format(&mut self, val: u8)

This bitfield is used to show which data bytes in a 32-bit word are valid

pub const fn irq_on_alternate_fields(&self) -> bool

If this bit is set, the LCDIF block will assert the cur_frame_done interrupt only on alternate fields, otherwise it will issue the interrupt on both odd and even field

pub const fn set_irq_on_alternate_fields(&mut self, val: bool)

If this bit is set, the LCDIF block will assert the cur_frame_done interrupt only on alternate fields, otherwise it will issue the interrupt on both odd and even field

pub const fn fifo_clear(&self) -> bool

Set this bit to clear all the data in the latency FIFO (LFIFO), TXFIFO and the RXFIFO.

pub const fn set_fifo_clear(&mut self, val: bool)

Set this bit to clear all the data in the latency FIFO (LFIFO), TXFIFO and the RXFIFO.

pub const fn start_interlace_from_second_field(&self) -> bool

The default is to grab the odd lines first and then the even lines

pub const fn set_start_interlace_from_second_field(&mut self, val: bool)

The default is to grab the odd lines first and then the even lines

pub const fn interlace_fields(&self) -> bool

Set this bit if it is required that the LCDIF block fetches odd lines in one field and even lines in the other field

pub const fn set_interlace_fields(&mut self, val: bool)

Set this bit if it is required that the LCDIF block fetches odd lines in one field and even lines in the other field

pub const fn recover_on_underflow(&self) -> bool

Set this bit to enable the LCDIF block to recover in the next field/frame if there was an underflow in the current field/frame

pub const fn set_recover_on_underflow(&mut self, val: bool)

Set this bit to enable the LCDIF block to recover in the next field/frame if there was an underflow in the current field/frame

pub const fn bm_error_irq(&self) -> bool

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn set_bm_error_irq(&mut self, val: bool)

This bit is set to indicate that an interrupt is requested by the LCDIF block

pub const fn bm_error_irq_en(&self) -> bool

This bit is set to enable bus master error interrupt in the LCDIF master mode.

pub const fn set_bm_error_irq_en(&mut self, val: bool)

This bit is set to enable bus master error interrupt in the LCDIF master mode.

pub const fn cs_out_select(&self) -> bool

This bit is CS0/CS1 valid select signals

pub const fn set_cs_out_select(&mut self, val: bool)

This bit is CS0/CS1 valid select signals

pub const fn image_data_select(&self) -> bool

Command Mode MIPI image data select bit

pub const fn set_image_data_select(&mut self, val: bool)

Command Mode MIPI image data select bit