nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

CtrlTog

Struct CtrlTog 

#[repr(transparent)]
pub struct CtrlTog(pub u32);
LCDIF General Control Register

Tuple Fields

0: u32

Implementations

Source

impl CtrlTog

pub const fn run(&self) -> bool

When this bit is set by software, the LCDIF will begin transferring data between the SoC and the display

pub const fn set_run(&mut self, val: bool)

When this bit is set by software, the LCDIF will begin transferring data between the SoC and the display

pub const fn data_format_24_bit(&self) -> CtrlTogDataFormat24Bit

Used only when WORD_LENGTH = 3, i

pub const fn set_data_format_24_bit(&mut self, val: CtrlTogDataFormat24Bit)

Used only when WORD_LENGTH = 3, i

pub const fn data_format_18_bit(&self) -> CtrlTogDataFormat18Bit

Used only when WORD_LENGTH = 2, i.e. 18-bit.

pub const fn set_data_format_18_bit(&mut self, val: CtrlTogDataFormat18Bit)

Used only when WORD_LENGTH = 2, i.e. 18-bit.

pub const fn data_format_16_bit(&self) -> bool

When this bit is 1 and WORD_LENGTH = 0, it implies that the 16-bit data is in ARGB555 format

pub const fn set_data_format_16_bit(&mut self, val: bool)

When this bit is 1 and WORD_LENGTH = 0, it implies that the 16-bit data is in ARGB555 format

pub const fn master(&self) -> bool

Set this bit to make the LCDIF act as a bus master

pub const fn set_master(&mut self, val: bool)

Set this bit to make the LCDIF act as a bus master

pub const fn enable_pxp_handshake(&self) -> bool

If this bit is set and LCDIF_MASTER bit is set, the LCDIF will act as bus master and the handshake mechanism between LCDIF and PXP will be turned on

pub const fn set_enable_pxp_handshake(&mut self, val: bool)

If this bit is set and LCDIF_MASTER bit is set, the LCDIF will act as bus master and the handshake mechanism between LCDIF and PXP will be turned on

pub const fn word_length(&self) -> CtrlTogWordLength

Input data format.

pub const fn set_word_length(&mut self, val: CtrlTogWordLength)

Input data format.

pub const fn lcd_databus_width(&self) -> CtrlTogLcdDatabusWidth

LCD Data bus transfer width. When LUT enabled, this field should be set to 0x01.

pub const fn set_lcd_databus_width(&mut self, val: CtrlTogLcdDatabusWidth)

LCD Data bus transfer width. When LUT enabled, this field should be set to 0x01.

pub const fn csc_data_swizzle(&self) -> CtrlTogCscDataSwizzle

This field specifies how to swap the bytes after the data has been converted into an internal representation of 24 bits per pixel and before it is transmitted over the LCD interface bus

pub const fn set_csc_data_swizzle(&mut self, val: CtrlTogCscDataSwizzle)

This field specifies how to swap the bytes after the data has been converted into an internal representation of 24 bits per pixel and before it is transmitted over the LCD interface bus

pub const fn input_data_swizzle(&self) -> CtrlTogInputDataSwizzle

This field specifies how to swap the bytes fetched by the bus master interface

pub const fn set_input_data_swizzle(&mut self, val: CtrlTogInputDataSwizzle)

This field specifies how to swap the bytes fetched by the bus master interface

pub const fn dotclk_mode(&self) -> bool

Set this bit to 1 to make the hardware go into the DOTCLK mode, i

pub const fn set_dotclk_mode(&mut self, val: bool)

Set this bit to 1 to make the hardware go into the DOTCLK mode, i

pub const fn bypass_count(&self) -> bool

When this bit is 0, it means that LCDIF will stop the block operation and turn off the RUN bit after the amount of data indicated by the LCDIF_TRANSFER_COUNT register has been transferred out

pub const fn set_bypass_count(&mut self, val: bool)

When this bit is 0, it means that LCDIF will stop the block operation and turn off the RUN bit after the amount of data indicated by the LCDIF_TRANSFER_COUNT register has been transferred out

pub const fn shift_num_bits(&self) -> u8

The data to be transmitted is shifted left or right by this number of bits.

pub const fn set_shift_num_bits(&mut self, val: u8)

The data to be transmitted is shifted left or right by this number of bits.

pub const fn data_shift_dir(&self) -> CtrlTogDataShiftDir

Use this bit to determine the direction of shift of transmit data.

pub const fn set_data_shift_dir(&mut self, val: CtrlTogDataShiftDir)

Use this bit to determine the direction of shift of transmit data.

pub const fn clkgate(&self) -> bool

This bit must be set to zero for normal operation

pub const fn set_clkgate(&mut self, val: bool)

This bit must be set to zero for normal operation

pub const fn sftrst(&self) -> bool

This bit must be set to zero to enable normal operation of the LCDIF

pub const fn set_sftrst(&mut self, val: bool)

This bit must be set to zero to enable normal operation of the LCDIF