nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Lut0Data

Struct Lut0Data 

#[repr(transparent)]
pub struct Lut0Data(pub u32);
Lookup Table 0 Data Register

Tuple Fields

0: u32

Implementations

Source

impl Lut0Data

pub const fn data(&self) -> u32

Writing this field will load 4 bytes, aligned to four byte boundaries, of data indexed by the ADDR field of the REG_LUT_CTRL register

pub const fn set_data(&mut self, val: u32)

Writing this field will load 4 bytes, aligned to four byte boundaries, of data indexed by the ADDR field of the REG_LUT_CTRL register