nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Pigeon102

Struct Pigeon102 

#[repr(transparent)]
pub struct Pigeon102(pub u32);
Panel Interface Signal Generator Register

Tuple Fields

0: u32

Implementations

Source

impl Pigeon102

pub const fn sig_logic(&self) -> Pigeon102SigLogic

Logic operation with another signal: DIS/AND/OR/COND

pub const fn set_sig_logic(&mut self, val: Pigeon102SigLogic)

Logic operation with another signal: DIS/AND/OR/COND

pub const fn sig_another(&self) -> Pigeon102SigAnother

Select another signal for logic operation or as mask or counter tick event

pub const fn set_sig_another(&mut self, val: Pigeon102SigAnother)

Select another signal for logic operation or as mask or counter tick event