nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Stat

Struct Stat 

#[repr(transparent)]
pub struct Stat(pub u32);
LCD Interface Status Register

Tuple Fields

0: u32

Implementations

Source

impl Stat

pub const fn lfifo_count(&self) -> u16

Read only view of the current count in Latency buffer (LFIFO).

pub const fn set_lfifo_count(&mut self, val: u16)

Read only view of the current count in Latency buffer (LFIFO).

pub const fn txfifo_empty(&self) -> bool

Read only view of the signals that indicates LCD TXFIFO is empty.

pub const fn set_txfifo_empty(&mut self, val: bool)

Read only view of the signals that indicates LCD TXFIFO is empty.

pub const fn txfifo_full(&self) -> bool

Read only view of the signals that indicates LCD TXFIFO is full.

pub const fn set_txfifo_full(&mut self, val: bool)

Read only view of the signals that indicates LCD TXFIFO is full.

pub const fn lfifo_empty(&self) -> bool

Read only view of the signals that indicates LCD LFIFO is empty.

pub const fn set_lfifo_empty(&mut self, val: bool)

Read only view of the signals that indicates LCD LFIFO is empty.

pub const fn lfifo_full(&self) -> bool

Read only view of the signals that indicates LCD LFIFO is full.

pub const fn set_lfifo_full(&mut self, val: bool)

Read only view of the signals that indicates LCD LFIFO is full.

pub const fn dma_req(&self) -> bool

Reflects the current state of the DMA Request line for the LCDIF

pub const fn set_dma_req(&mut self, val: bool)

Reflects the current state of the DMA Request line for the LCDIF

pub const fn present(&self) -> bool

0: LCDIF not present on this product 1: LCDIF is present.

pub const fn set_present(&mut self, val: bool)

0: LCDIF not present on this product 1: LCDIF is present.